#!perl
use 5.010;
use strict;
use warnings;

use Acme::StringFormat;

say '[%s, %s!]' % 'Hello' % 'world';
